==> servicecatalog-annotations-0.10.11-sources.jar: io/dekorate/servicecatalog/config/ParameterFluentImpl.java <==
package io.dekorate.servicecatalog.config;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ParameterFluentImpl<A extends ParameterFluent<A>> extends io.dekorate.deps.kubernetes.api.builder.BaseFluent<A> implements ParameterFluent<A>{

    private String key;
    private String value;

    public ParameterFluentImpl(){
    }
    public ParameterFluentImpl(io.dekorate.servicecatalog.config.Parameter instance){
            this.withKey(instance.getKey()); 
            this.withValue(instance.getValue()); 
    }

    public String getKey(){
            return this.key;
    }

    public A withKey(String key){
            this.key=key; return (A) this;
    }

    public Boolean hasKey(){
            return this.key != null;
    }

    public A withNewKey(String arg1){
            return (A)withKey(new String(arg1));
    }

    public A withNewKey(StringBuilder arg1){
            return (A)withKey(new String(arg1));
    }

    public A withNewKey(StringBuffer arg1){
            return (A)withKey(new String(arg1));
    }

    public String getValue(){
            return this.value;
    }

    public A withValue(String value){
            this.value=value; return (A) this;
    }

    public Boolean hasValue(){
            return this.value != null;
    }

    public A withNewValue(String arg1){
            return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuilder arg1){
            return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuffer arg1){
            return (A)withValue(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ParameterFluentImpl that = (ParameterFluentImpl) o;
            if (key != null ? !key.equals(that.key) :that.key != null) return false;
            if (value != null ? !value.equals(that.value) :that.value != null) return false;
            return true;
    }




}

==> servicecatalog-annotations-0.11.1-sources.jar: io/dekorate/servicecatalog/config/ParameterFluentImpl.java <==
package io.dekorate.servicecatalog.config;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import io.dekorate.deps.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ParameterFluentImpl<A extends ParameterFluent<A>> extends BaseFluent<A> implements ParameterFluent<A>{

    private String key;
    private String value;

    public ParameterFluentImpl(){
    }
    public ParameterFluentImpl(io.dekorate.servicecatalog.config.Parameter instance){
            this.withKey(instance.getKey()); 
            this.withValue(instance.getValue()); 
    }

    public String getKey(){
            return this.key;
    }

    public A withKey(String key){
            this.key=key; return (A) this;
    }

    public Boolean hasKey(){
            return this.key != null;
    }

    public A withNewKey(String arg1){
            return (A)withKey(new String(arg1));
    }

    public A withNewKey(StringBuilder arg1){
            return (A)withKey(new String(arg1));
    }

    public A withNewKey(StringBuffer arg1){
            return (A)withKey(new String(arg1));
    }

    public String getValue(){
            return this.value;
    }

    public A withValue(String value){
            this.value=value; return (A) this;
    }

    public Boolean hasValue(){
            return this.value != null;
    }

    public A withNewValue(String arg1){
            return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuilder arg1){
            return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuffer arg1){
            return (A)withValue(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ParameterFluentImpl that = (ParameterFluentImpl) o;
            if (key != null ? !key.equals(that.key) :that.key != null) return false;
            if (value != null ? !value.equals(that.value) :that.value != null) return false;
            return true;
    }




}
